@@ -46,9 +46,7 @@ public:
     {
     }
 
-    ~LoginJobPrivate() override
-    {
-    }
+    ~LoginJobPrivate() override = default;
 
     bool sasl_interact();
     bool sasl_init();
@@ -57,8 +55,8 @@ public:
     bool authenticate();
     bool selectAuthentication();
 
-    LoginJob::AuthMode authModeFromCommand(const QByteArray &mech) const;
-    QByteArray authCommand(LoginJob::AuthMode mode) const;
+    Q_REQUIRED_RESULT LoginJob::AuthMode authModeFromCommand(const QByteArray &mech) const;
+    Q_REQUIRED_RESULT QByteArray authCommand(LoginJob::AuthMode mode) const;
 
     QString m_userName;
     QString m_password;
@@ -80,9 +78,7 @@ LoginJob::LoginJob(Session *session)
 {
 }
 
-LoginJob::~LoginJob()
-{
-}
+LoginJob::~LoginJob() = default;
 
 void LoginJob::setUserName(const QString &userName)
 {
